@@ -2,7 +2,7 @@
 Pandas Selector
 ---------------
 
-Simple column selector for ``loc[]``, ``iloc[]``, ``assign()`` and others. Juse use ``DF``.
+Simple, composable column selector for ``loc[]``, ``iloc[]``, ``assign()`` and others. Juse use ``DF``.
 
 Filter rows:
 
@@ -63,7 +63,7 @@ Chain operations:
 
 Author: Eike von Seggern <eike@vonseggern.space>
 """
-__version__ = "0.1.0"
+__version__ = "0.1.1"
 __all__ = ["DF"]
 
 from .accessor import DataframeAccessor
